/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package wordsreminder;

/**
 * Interface of a dictionary.
 * 
 * @author Jacek Koleyski
 */
public interface IDictionary {
	// ~ Methods
	// --------------------------------------------------------------------------------------------------------

	/**
	 * Adds a term to the dictionary.
	 * 
	 * @param term
	 *            term to be added
	 * 
	 * @return term which has been added
	 */
	public ITerm addToDictionary(ITerm term);

	/**
	 * Adds a term to the dictionary, in String form.
	 * 
	 * @param wordWithTranslation
	 *            string representing a term, word and translation
	 * 
	 * @return term which has been added
	 */
	public ITerm addToDictionary(String wordWithTranslation);

	/**
	 * Removes a term from the dictionary.
	 * 
	 * @param term
	 *            term to be removed
	 * 
	 * @return term which has been removed
	 */
	public ITerm removeFromDictionary(ITerm term);

	public void removeAll();

	/**
	 * Gets a random term from the dictionary.
	 * 
	 * @return random term
	 */
	public ITerm getRandomTerm();

	/**
	 * Orders the dictionary to save changes.
	 */
	public void save();

	/**
	 * Checks if the dictionary contains the term.
	 * 
	 * @param term
	 *            term to be checked
	 * 
	 * @return true if dictionary contains the term, false otherwise
	 */
	public boolean contains(ITerm term);

	/**
	 * Checks if the dictionary is empty.
	 * 
	 * @return true if dictionary is empty, false otherwise
	 */
	public boolean isEmpty();
}
